<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\ItemsResource;
use App\Http\Resources\OfferSlidersResource;
use App\Models\Brand;
use App\Models\Category;
use App\Models\Complaint;
use App\Models\CouponReview;
use App\Models\FavouriteItem;
use App\Models\Help;
use App\Models\Item;
use App\Models\OfferSlider;
use App\Models\SuggestCoupon;
use App\Models\UsedCoupon;
use Carbon\Carbon;
use Illuminate\Http\Request;
use JWTAuth;
use function GuzzleHttp\Psr7\uri_for;

class CouponsController extends Controller
{
    public function home($category_id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        if ($category_id == 0) {
            $rows = Item::orderByDesc('id')->where('offer', 'false')->paginate(10);
        } else {
            $rows = Item::whereCategoryId($category_id)->where('offer', 'false')->orderByDesc('id')->paginate(10);
        }

        return ItemsResource::collection($rows)->additional([
            'value' => true
        ]);

    }

    public function offers_coupons()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);

        $rows = Item::orderByDesc('id')->where('offer', 'true')->paginate(10);

        return ItemsResource::collection($rows)->additional([
            'value' => true
        ]);

    }

    public function use_coupon($coupon_id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $item = Item::find($coupon_id);
        $item->used_count += 1;
        $item->last_used = Carbon::now();
        $item->update();
        $check = UsedCoupon::where(['user_id' => $user->id, 'item_id' => $coupon_id])->first();
        if (!$check) {
            UsedCoupon::create(['user_id' => $user->id, 'item_id' => $coupon_id]);
        }

        return response()->json(['value' => true, 'data' => \Lang::get('data.success')]);

    }

    public function delete_used_coupon($coupon_id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $check = UsedCoupon::where(['user_id' => $user->id, 'item_id' => $coupon_id])->first();
        if ($check) {
            $check->delete();
        }

        return response()->json(['value' => true, 'data' => \Lang::get('data.success')]);

    }

    public function coupon_review(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'coupon_id' => 'required|exists:items,id',
            'status' => 'required|in:good,bad'
        ]);


        if ($validator->passes()) {

            CouponReview::create([
                'user_id' => $user->id,
                'item_id' => $request['coupon_id'],
                'status' => $request['status']
            ]);


            return response()->json(['value' => true, 'data' => \Lang::get('data.success')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);

        }


    }

    public function favourite_coupon(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'coupon_id' => 'required|exists:items,id'
        ]);
        if ($validator->passes()) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }

            $check = FavouriteItem::where(['user_id' => $user->id, 'item_id' => $request['coupon_id']])->first();

            if ($check) {
                $check->delete();
            } else {
                FavouriteItem::create(['user_id' => $user->id, 'item_id' => $request['coupon_id']]);
            }

            return response()->json(['value' => true, 'data' => \Lang::get('data.success')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function filter(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'categories' => 'nullable',
            'order_by' => 'required'
        ]);
        if ($validator->passes()) {

            $categories = explode(",", $request['categories']);
            $rows = Item::where('offer', 'false');
            if ($request['order_by']) {
                if ($request['order_by'] == 'high_discount') {
                    $rows->orderByDesc('discount_percent');
                } elseif ($request['order_by'] == 'alpha_asc') {

                    $rows->orderBy('description->' . \App::getLocale(), 'asc');
                } elseif ($request['order_by'] == 'alpha_desc') {
                    $rows->orderBy('description->' . \App::getLocale(), 'desc');

                }
            }

            if ($request['categories']) {
                $rows->whereIn('category_id', $categories);
            }
            $rows = $rows->paginate(10);
            return ItemsResource::collection($rows)->additional(['value' => true]);


        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function search(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'search' => 'required',
        ]);
        if ($validator->passes()) {
            $brands = Brand::where('name->' . \App::getLocale(), 'LIKE', "%{$request->search}%")->pluck('id');
            if (count($brands) > 0) {
                $rows = Item::whereIn('brand_id', $brands)->where('offer', 'false')->orderByDesc('id')->paginate(10);
            } else {
                $rows = Item::where('description->' . \App::getLocale(), 'LIKE', "%{$request->search}%")->where('offer', 'false')->orderByDesc('id')->paginate(10);
            }
            return ItemsResource::collection($rows)->additional(['value' => true]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);

        }
    }

    public function offers_sliders(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $rows = OfferSlider::orderByDesc('id')->get();
        return OfferSlidersResource::collection($rows)->additional(['value' => true]);
    }

    public function favourites()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $rows = $user->favourite_items()->paginate(10);
        return ItemsResource::collection($rows)->additional([
            'value' => true
        ]);
    }

    public function used_coupons()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $rows = $user->used_coupons()->paginate(10);
        return ItemsResource::collection($rows)->additional([
            'value' => true
        ]);
    }

    public function suggest_coupon(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'full_name' => 'required',
            'email' => 'required',
            'whatsapp' => 'required',
            'address' => 'required',
            'coupon_code' => 'required',
            'category_id' => 'required|exists:categories,id',
            'discount_percent'=>'required'
        ]);
        if ($validator->passes()) {

            SuggestCoupon::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.sent_success')]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }

    }

    public function send_help(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'brand' => 'required',
            'email' => 'required',
            'address' => 'required',
            'message' => 'required',
            'coupon' => 'required',
        ]);
        if ($validator->passes()) {

            Help::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.contact_sent')]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }

    }

    public function complaints(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'title' => 'required',
            'email' => 'required',
            'body' => 'required',
            'brand' => 'required',
            'coupon' => 'required',
        ]);
        if ($validator->passes()) {

            Complaint::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.contact_sent')]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
}
